@@ -117,6 +117,7 @@ class StateService:
                 file_id INTEGER PRIMARY KEY AUTOINCREMENT,
                 course_id integer NOT NULL,
                 course_fullname integer NOT NULL,
+                course_category_id integer NULL,
                 module_id integer NOT NULL,
                 section_name text NOT NULL,
                 module_name text NOT NULL,
@@ -140,7 +141,7 @@ class StateService:
 
                 sql_create_new_files_table_3 = """
                 INSERT INTO files
-                (course_id, course_fullname, module_id, section_name,
+                (course_id, course_fullname, course_category_id, module_id, section_name,
                  module_name, content_filepath, content_filename,
                  content_fileurl, content_filesize, content_timemodified,
                  module_modname, content_type, content_isexternalfile,
